package com.inspect.metadata.threshold.mapper;

import com.inspect.metadata.threshold.domain.BasedataThresholdModification;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface BasedataThresholdModificationMapper {
    BasedataThresholdModification selectBasedataThresholdModificationByLineId(Long lineId);

    List<BasedataThresholdModification> selectBasedataThresholdModificationList(BasedataThresholdModification modification);

    int insertBasedataThresholdModification(BasedataThresholdModification modification);

    int updateBasedataThresholdModification(BasedataThresholdModification modification);

    int deleteBasedataThresholdModificationByLineId(Long lineId);

    int deleteBasedataThresholdModificationByLineIds(Long[] lineIds);
}
